@@ -1,12 +1,13 @@
-; Created:    <97/08/22 12:49:31 teranisi>
-; Time-stamp: <99/11/22 18:42:31 teranisi>
-;; select-xface.el --- select xfaces graphically.
+;;; select-xface.el --- Select X-Faces graphically
 
-;; Copyright (C) 1997,1998,1999 Yuuichi Teranishi
+; Created:    <97/08/22 12:49:31 teranisi>
+; Time-stamp: <2002-02-17 23:46:09 teranisi>
+
+;; Copyright (C) 1997-2002 Yuuichi Teranishi
 
 ;; Author: Yuuichi Teranishi <teranisi@gohome.org>
 ;; Maintainer: Yuuichi Teranishi <teranisi@gohome.org>
-;; Version: 0.13
+;; Version: 0.15
 ;; Target: Emacs, Mule, XEmacs
 
 ;; Select X-Face is free software; you can redistribute it and/or modify
@@ -24,15 +25,14 @@
 ;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 ;; Boston, MA 02111-1307, USA.
 
-;;
 ;; Setup:
 ;;
-;; (require 'select-xface)
+;; (autoload 'select-xface "select-xface" "Select X-Face" t)
 ;;
-;; For Mew: 
+;; For Mew:
 ;; (add-hook 'mew-draft-mode-hook
 ;;	  (lambda ()
-;;	    (define-key (current-local-map) "\C-c\C-x" 
+;;	    (define-key (current-local-map) "\C-c\C-x"
 ;;	      'select-xface)))
 ;;
 ;; For Gnus:
@@ -50,17 +50,18 @@
 ;;	  (lambda ()
 ;;	    (define-key (current-local-map) "\C-x4x"
 ;;	      'select-xface)))
-;;
-(provide 'select-xface)
+
+;;; Commentary:
+;; 
+
+;;; Code:
 
 (defconst select-xface-appname "Select X-Face")
-(defconst select-xface-version-number "v0.14")
-(defconst select-xface-codename 
-  "Keep Under Cover"
-  )
+(defconst select-xface-version-number "v0.15")
+(defconst select-xface-codename "Live And Let Die")
 
-(defconst select-xface-version 
-  (concat select-xface-appname " " 
+(defconst select-xface-version
+  (concat select-xface-appname " "
 	  select-xface-version-number " - \""
 	  select-xface-codename "\""))
 
@@ -76,10 +77,10 @@
 (defvar select-xface-field-insert-before "^X-Mailer:\\|^User-Agent:\\|^--"
   "*insert xface field before this regexp.")
 
-(defvar select-xface-mode-hook nil 
+(defvar select-xface-mode-hook nil
   "*hooks to be called after select-xface-mode starts.")
 
-(defvar select-xface-insert-hook nil 
+(defvar select-xface-insert-hook nil
   "*hooks to be called after xface is inserted.")
 
 (defvar select-xface-candidate-regexp "^[^.].*"
@@ -94,8 +95,8 @@
 (defvar select-xface-header-separator-regexp "\\(^--.*$\\)\\|\\(\n\n\\)"
   "*header separator. (regexp)")
 
-(defvar select-xface-display-func 
-  (function 
+(defvar select-xface-display-func
+  (function
    (lambda (beg end)
      (cond
       ((featurep 'xemacs)
@@ -103,20 +104,8 @@
        (let ((highlight-headers-hack-x-face-p t)
 	     (x-face-xmas-like-highlight-headers nil))
 	 (highlight-headers beg end nil)))
-      ((and (featurep 'mule)
-	    window-system)
-       (cond
-	((fboundp 'x-face-mule:x-face-decode-message-header)
-	 (let ((x-face-mule:highlight-x-face-position 'from)
-	       (x-face-mule-highlight-x-face-position 'from)
-	       )
-	   (x-face-mule:x-face-decode-message-header beg end)))
-	((fboundp 'x-face-mule-x-face-decode-message-header)
-	 (let ((x-face-mule-highlight-x-face-position 'from))
-	   (x-face-mule-x-face-decode-message-header beg end)))
-	((fboundp 'mew-x-face-decode-message-header)
-	 (let ((mew-opt-highlight-x-face-type 'from))
-	   (mew-x-face-decode-message-header beg end)))))
+      ((fboundp 'x-face-decode-message-header)
+       (x-face-decode-message-header beg end))
       (t nil))))
   "xface display function.")
 
@@ -163,7 +152,7 @@
   "define popup menu."
   (if (not select-xface-popup-menu)
       (easy-menu-define
-       select-xface-popup-menu 
+       select-xface-popup-menu
        select-xface-mode-map "Menu for Select X-Face"
        '("Select X-Face"
 	 ["Prev"   select-xface-prev-face       t]
@@ -178,7 +167,7 @@
   (easy-menu-add select-xface-popup-menu))
   
 
-(defun select-xface-mode () 
+(defun select-xface-mode ()
 ;;a up    select-xface-append-out-top    append the current as the top face
 ;;a down  select-xface-append-out-bottom append the current as the bottom face
 "Major mode for select and insert X-Face: field in the current draft buffer.
@@ -212,7 +201,7 @@ q       select-xface-exit              quit selecting face
   (save-excursion
     (goto-char (point-min))
     (while (re-search-forward
-	    "^\\(X-Face.*:\\) *\\(.*\\(\n[ \t].*\\)*\\)\n" 
+	    "^\\(X-Face.*:\\) *\\(.*\\(\n[ \t].*\\)*\\)\n"
 	    (select-xface-header-end) t)
       (delete-region (match-beginning 0) (match-end 0))
       (goto-char (point-min)))))
@@ -224,10 +213,10 @@ q       select-xface-exit              quit selecting face
 	ret)
     (save-excursion
       (goto-char (point-min))
-      (while (re-search-forward 
-	      "\\(^\\(X-Face-Type:\\)[ \t]*\\(.*\\(\n[ \t].*\\)*\\)\n\\)\\|\\(^\\(X-Face:\\)[ \t]*\\(.*\\(\n[ \t].*\\)*\\)\n\\)" end t)
-	(setq ret (concat ret 
-			  (buffer-substring (match-beginning 0) 
+      (while (re-search-forward
+	      "\\(^\\(X-Face-Type:\\)[ \t]*\\(.*\\(\n[ \t].*\\)*\\)\n\\)\\|\\(^\\(X-Face[-0-9]*:\\)[ \t]*\\(.*\\(\n[ \t].*\\)*\\)\n\\)" end t)
+	(setq ret (concat ret
+			  (buffer-substring (match-beginning 0)
 					    (match-end 0)))))
       (if ret
 	  (let ((ret-len (length ret)))
@@ -262,20 +251,20 @@ q       select-xface-exit              quit selecting face
   (select-xface-insert (select-xface-make-out-xface)
 		       'bottom))
 
-(defun select-xface-make-append-xface (current-xface 
-				       out-xface 
+(defun select-xface-make-append-xface (current-xface
+				       out-xface
 				       direction)
   "append the current face in the specified direction."
   (interactive)
   (let (insert-str)
     (cond
      ((eq direction 'top)
-      (setq insert-str 
+      (setq insert-str
 	    (concat "X-Face-Type: geometry=1x2\n"
 		    out-xface
 		    current-xface "\n")))
      ((eq direction 'first)
-      (setq insert-str 
+      (setq insert-str
 	    (concat ;; "X-Face-Type: geometry=2x1\n"
 		    out-xface "\n"
 		    current-xface)))
@@ -286,7 +275,7 @@ q       select-xface-exit              quit selecting face
 		    out-xface)))
      (t ;; last or other
       (setq insert-str
-	    (concat ;; "X-Face-Type: geometry=2x1\n" 
+	    (concat ;; "X-Face-Type: geometry=2x1\n"
 		    (if current-xface (concat current-xface "\n"))
 		    out-xface))))
     insert-str
@@ -311,7 +300,7 @@ q       select-xface-exit              quit selecting face
       (save-excursion
 	(set-buffer select-xface-parent-buffer)
 	(if append-direction
-	    (setq current-xface 
+	    (setq current-xface
 		  (select-xface-collect-xface-related-fields)))
 	(select-xface-delete-all-xface-related-fields)
 	(goto-char (point-min))
@@ -319,7 +308,7 @@ q       select-xface-exit              quit selecting face
 	(beginning-of-line)
 	(setq beg (point))
 	(if append-direction
-	    (insert (select-xface-make-append-xface current-xface 
+	    (insert (select-xface-make-append-xface current-xface
 						    out-xface
 						    append-direction))
 	  (insert out-xface))
@@ -333,7 +322,7 @@ q       select-xface-exit              quit selecting face
 	      (if (not (eq beg (point)))
 		  (progn
 		    (put-text-property beg (point) 'invisible nil)
-		    (insert (concat "                with " 
+		    (insert (concat "                with "
 				    select-xface-version "\n")))))
 	  (if select-xface-add-x-face-version-header
 	      (insert (concat "X-Face-Version: " select-xface-version "\n"))))
@@ -362,7 +351,7 @@ q       select-xface-exit              quit selecting face
   (save-excursion
     (goto-char (point-min))
     (while (re-search-forward (concat "\\(" string "\\)") nil t)
-      (put-text-property 
+      (put-text-property
        (match-beginning 1) (match-end 1) 'invisible t))))
 
 (defun select-xface-set-list-pos (pos)
@@ -378,7 +367,7 @@ q       select-xface-exit              quit selecting face
     (if (not entry)
 	()
       (if (string-match "^X-Face-Type: .*\n" entry)
-	  (progn 
+	  (progn
 	    (insert "From: \n")
 	    (insert entry)
 	    (insert "\n")
@@ -405,7 +394,7 @@ q       select-xface-exit              quit selecting face
 	  (backward-char 1)))
       (set-buffer-modified-p nil)
       (rename-buffer (concat select-xface-appname "(" xface-name ")"))
-      (setq select-xface-buffer (concat 
+      (setq select-xface-buffer (concat
 				 select-xface-appname "(" xface-name ")"))
       )))
 
@@ -420,7 +409,7 @@ q       select-xface-exit              quit selecting face
 (defun select-xface-make-candidate-list (path)
   "make file list in the path."
   (let (ret files attr)
-    (setq ret 
+    (setq ret
 	  (directory-files path nil select-xface-candidate-regexp nil))
     (setq ret (delete "." ret))
     (setq ret (delete ".." ret))
@@ -470,7 +459,7 @@ q       select-xface-exit              quit selecting face
 (defun select-xface-make-xface-string (candidate-name directory)
   "make xface string from face file."
   (save-excursion
-    (let ((tmp-buffer (get-buffer-create (concat 
+    (let ((tmp-buffer (get-buffer-create (concat
 					  "*Select-X-Face-"
 					  (expand-file-name candidate-name
 							    directory)
@@ -481,7 +470,7 @@ q       select-xface-exit              quit selecting face
 	  format-alist jka-compr-compression-info-list
 	  child-clist ret-string)
       (set-buffer tmp-buffer)
-      (if (not (file-directory-p 
+      (if (not (file-directory-p
 		(expand-file-name candidate-name
 				  directory)))
 	  (progn
@@ -495,11 +484,11 @@ q       select-xface-exit              quit selecting face
 			  (x-face-insert
 			   (expand-file-name candidate-name
 					     select-xface-directory))
-			(error 
+			(error
 			 (setq select-xface-candidate-list
-			       (delete candidate-name 
+			       (delete candidate-name
 				       select-xface-candidate-list))
-			 (message (format 
+			 (message (format
 				   "%s has illegal contents(ignored)."
 				   candidate-name))))
 		      (select-xface-reduce-needless-character-in-buffer)
@@ -508,43 +497,43 @@ q       select-xface-exit              quit selecting face
 	      ;;
 	      ;; xface file.
 	      ;;
-	      (insert-file-contents 
+	      (insert-file-contents
 	       (expand-file-name candidate-name directory))
 	      (if (looking-at "\x1f\x8b") ; gzipped?
-		  (call-process-region 
+		  (call-process-region
 		   (point-min) (point-max)
 		   select-xface-gzip-program t t nil "-cd"))
 	      (select-xface-reduce-needless-character-in-buffer)
 	      (goto-char (point-min))
 	      (if (not (re-search-forward "X-Face:" nil t))
 		  (insert "X-Face: ")))
-	    (setq ret-string 
-		  (select-xface-reduce-needless-character-in-string 
-		   (concat 
+	    (setq ret-string
+		  (select-xface-reduce-needless-character-in-string
+		   (concat
 		    (buffer-substring (point-min)
 				      (point-max))))))
 	;;
 	;; recursive subdirectory processing.
 	;;
-	(setq child-clist (select-xface-make-candidate-list 
+	(setq child-clist (select-xface-make-candidate-list
 			   (expand-file-name candidate-name
 					     directory)))
 	(if (select-xface-check-rgb child-clist)
 	    (progn
 	      (insert )
-	      (setq ret-string 
+	      (setq ret-string
 		    (concat "X-Face-Type: RGB; geometry=1x1\n"
 			    (select-xface-make-xface-string
 			     "red"
 			     (expand-file-name candidate-name directory))))
-	      (setq ret-string 
+	      (setq ret-string
 		    (concat ret-string "\n"
-			    (select-xface-make-xface-string 
+			    (select-xface-make-xface-string
 			     "green"
 			     (expand-file-name candidate-name directory))))
-	      (setq ret-string 
+	      (setq ret-string
 		    (concat ret-string "\n"
-			    (select-xface-make-xface-string 
+			    (select-xface-make-xface-string
 			     "blue"
 			     (expand-file-name candidate-name directory)))))
 ;;      (insert (format "X-Face-Type: geometry=%dx1\n"
@@ -555,8 +544,8 @@ q       select-xface-exit              quit selecting face
 	      (setq cur-cname (car child-clist))
 	      (setq ret-string
 		    (concat ret-string
-			    (select-xface-make-xface-string 
-			     cur-cname 
+			    (select-xface-make-xface-string
+			     cur-cname
 			     (expand-file-name candidate-name directory))
 			    "\n"
 			    ))
@@ -579,7 +568,7 @@ q       select-xface-exit              quit selecting face
     (catch 'loop
       (while flist
 	(if (string= face (car flist))
-	    (progn 
+	    (progn
 	      (setq found t)
 	      (throw 'loop nil))
 	  (setq flist (cdr flist))
@@ -613,14 +602,14 @@ q       select-xface-exit              quit selecting face
 (defun select-xface-make-face-list ()
   "make face list from directory."
   ;; if select-xface-candidate-list is nil, all files or directories
-  ;; that contain select-xface-candidate-regexp 
+  ;; that contain select-xface-candidate-regexp
   ;; in the select-xface-directory became the candidates.
   (if (not select-xface-candidate-list)
-      (setq select-xface-candidate-list 
+      (setq select-xface-candidate-list
 	    (select-xface-make-candidate-list select-xface-directory)))
   ;; make face list from candidate list.
   (if (not select-xface-face-list)
-      (select-xface-make-face-list-from-candidate-list 
+      (select-xface-make-face-list-from-candidate-list
        select-xface-candidate-list)))
   
 (defun select-xface-make-face-list-from-candidate-list (candidate-list)
@@ -630,7 +619,7 @@ q       select-xface-exit              quit selecting face
 	  (clist candidate-list))
       (while clist
 	(select-xface-add-face-to-face-list
-	 (select-xface-make-xface-string 
+	 (select-xface-make-xface-string
 	  (car clist) select-xface-directory)
 	 (car clist))
 	(setq clist (cdr clist)))
@@ -652,15 +641,15 @@ q       select-xface-exit              quit selecting face
     (select-xface-make-face-list)
   ;; add current face to candidate list.
     (let (pos)
-      (setq pos (select-xface-add-face-to-face-list 
+      (setq pos (select-xface-add-face-to-face-list
 		 (select-xface-collect-xface-related-fields)))
       (if select-xface-face-list
-	  (progn 
-	    (setq select-xface-orig-window-config 
+	  (progn
+	    (setq select-xface-orig-window-config
 		  (current-window-configuration))
 	    (if (get-buffer select-xface-buffer)
 		(select-xface-pop-to-buffer select-xface-buffer)
-	      (let* () 
+	      (let* ()
 		(select-xface-pop-to-buffer select-xface-buffer)
 		(enlarge-window (- select-xface-height (window-height)))
 		(select-xface-set-list-pos pos)
@@ -678,3 +667,5 @@ q       select-xface-exit              quit selecting face
   (kill-buffer select-xface-buffer)
 )
 
+(provide 'select-xface)
+;;; select-xface.el ends here
